@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2006 Red Hat, Inc.
+ * Copyright (c) 2006-2007 Red Hat, Inc.
  * Copyright (c) 2006 Sun Microsystems, Inc.
  *
  * All rights reserved.
@@ -171,6 +171,8 @@ static void message_handler_req_lib_cpg_trackstart (void *conn, void *message);
 
 static void message_handler_req_lib_cpg_trackstop (void *conn, void *message);
 
+static void message_handler_req_lib_cpg_local_get (void *conn, void *message);
+
 static int cpg_node_joinleave_send (struct group_info *gi, struct process_info *pi, int fn, int reason);
 
 static int cpg_exec_send_joinlist(void);
@@ -219,6 +221,12 @@ static struct openais_lib_handler cpg_lib_service[] =
 		.response_size				= sizeof (struct res_lib_cpg_trackstart),
 		.response_id				= MESSAGE_RES_CPG_TRACKSTOP,
 		.flow_control				= OPENAIS_FLOW_CONTROL_NOT_REQUIRED
+	},
+	{ /* 6 */
+		.lib_handler_fn				= message_handler_req_lib_cpg_local_get,
+		.response_size				= sizeof (struct res_lib_cpg_local_get),
+		.response_id				= MESSAGE_RES_CPG_LOCAL_GET,
+		.flow_control				= OPENAIS_FLOW_CONTROL_NOT_REQUIRED
 	}
 };
 
@@ -1191,3 +1199,16 @@ tstop_ret:
 	res_lib_cpg_trackstop.header.error = SA_AIS_OK;
 	openais_conn_send_response(conn, &res_lib_cpg_trackstop.header, sizeof(res_lib_cpg_trackstop));
 }
+
+static void message_handler_req_lib_cpg_local_get (void *conn, void *message)
+{
+	struct res_lib_cpg_local_get res_lib_cpg_local_get;
+
+	res_lib_cpg_local_get.header.size = sizeof(res_lib_cpg_local_get);
+	res_lib_cpg_local_get.header.id = MESSAGE_RES_CPG_LOCAL_GET;
+	res_lib_cpg_local_get.header.error = SA_AIS_OK;
+	res_lib_cpg_local_get.local_nodeid = this_ip->nodeid;
+
+	openais_conn_send_response(conn, &res_lib_cpg_local_get,
+		sizeof(res_lib_cpg_local_get));
+}
