@@ -1,10 +1,10 @@
 /*
  * Copyright (c) 2002-2006 MontaVista Software, Inc.
- * Copyright (c) 2006 Red Hat, Inc.
+ * Copyright (c) 2006-2007 Red Hat, Inc.
  *
  * All rights reserved.
  *
- * Author: Steven Dake (sdake@mvista.com)
+ * Author: Steven Dake (sdake@redhat.com)
  *
  * This software licensed under BSD license, the text of which follows:
  *
@@ -972,6 +972,7 @@ void message_source_set (
 	void *conn)
 {
 	assert ((source != NULL) && (conn != NULL));
+	memset (source, 0, sizeof (mar_message_source_t));
 	source->nodeid = my_ip->nodeid;
 	source->conn = conn;
 }
@@ -1224,44 +1225,6 @@ retry_sendmsg_two:
 	return (0);
 }
 
-int openais_ipc_timer_add (
-	void *conn,
-	void (*timer_fn) (void *data),
-	void *data,
-	unsigned int msec_in_future,
-	timer_handle *handle)
-{
-	struct conn_info *conn_info = (struct conn_info *)conn;
-	int res;
-
-	res = timerlist_add_future (
-		&conn_info->timerlist,
-		timer_fn,
-		data,
-		msec_in_future,
-		handle);
-
-	return (res);
-}
-
-void openais_ipc_timer_del (
-	void *conn,
-	timer_handle timer_handle)
-{
-	struct conn_info *conn_info = (struct conn_info *)conn;
-
-	timerlist_del (&conn_info->timerlist, timer_handle);
-}
-
-void openais_ipc_timer_del_data (
-	void *conn,
-	timer_handle timer_handle)
-{
-	struct conn_info *conn_info = (struct conn_info *)conn;
-
-	timerlist_del (&conn_info->timerlist, timer_handle);
-}
-
 void openais_ipc_flow_control_create (
 	void *conn,
 	unsigned int service,
