@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2006 Red Hat, Inc.
+ * Copyright (c) 2006-2007 Red Hat, Inc.
  *
  * All rights reserved.
  *
@@ -45,7 +45,8 @@ enum req_cpg_types {
 	MESSAGE_REQ_CPG_MCAST = 2,
 	MESSAGE_REQ_CPG_MEMBERSHIP = 3,
 	MESSAGE_REQ_CPG_TRACKSTART = 4,
-	MESSAGE_REQ_CPG_TRACKSTOP = 5
+	MESSAGE_REQ_CPG_TRACKSTOP = 5,
+	MESSAGE_REQ_CPG_LOCAL_GET = 6
 };
 
 enum res_cpg_types {
@@ -56,7 +57,8 @@ enum res_cpg_types {
 	MESSAGE_RES_CPG_CONFCHG_CALLBACK = 4,
 	MESSAGE_RES_CPG_DELIVER_CALLBACK = 5,
 	MESSAGE_RES_CPG_TRACKSTART = 6,
-	MESSAGE_RES_CPG_TRACKSTOP = 7
+	MESSAGE_RES_CPG_TRACKSTOP = 7,
+	MESSAGE_RES_CPG_LOCAL_GET = 8,
 };
 
 enum lib_cpg_confchg_reason {
@@ -97,6 +99,15 @@ struct res_lib_cpg_trackstop {
 	mar_res_header_t header __attribute__((aligned(8)));
 };
 
+struct req_lib_cpg_local_get {
+	mar_req_header_t header __attribute__((aligned(8)));
+};
+
+struct res_lib_cpg_local_get {
+	mar_res_header_t header __attribute__((aligned(8)));
+	mar_uint32_t local_nodeid __attribute__((aligned(8)));
+};
+
 struct req_lib_cpg_mcast {
 	mar_res_header_t header __attribute__((aligned(8)));
 	mar_uint32_t guarantee __attribute__((aligned(8)));
