@@ -1,9 +1,10 @@
 /*
  * Copyright (c) 2002-2003 MontaVista Software, Inc.
+ * Copyright (c) 2006-2007 Red Hat, Inc.
  *
  * All rights reserved.
  *
- * Author: Steven Dake (sdake@mvista.com)
+ * Author: Steven Dake (sdake@redhat.com)
  *
  * This software licensed under BSD license, the text of which follows:
  * 
@@ -187,8 +188,8 @@ typedef struct {
 
 typedef struct {
 	SaUint32T numberOfItems;
-	SaAmfProtectionGroupNotificationT *notificaton;
-} SaAmfProtectionGruopNotificationBufferT;
+	SaAmfProtectionGroupNotificationT *notification;
+} SaAmfProtectionGroupNotificationBufferT;
 
 typedef enum {
 	SA_AMF_NO_RECOMMENDATION = 1,
@@ -261,7 +262,7 @@ typedef void (*SaAmfExternalComponentCleanupCallbackT) (
 
 typedef void (*SaAmfProtectionGroupTrackCallbackT) (
 	const SaNameT *csiName,
-	SaAmfProtectionGroupNotificationT *notificationBuffer,
+	SaAmfProtectionGroupNotificationBufferT *notificationBuffer,
 	SaUint32T numberOfMembers,
 	SaAisErrorT error);
 
@@ -277,9 +278,9 @@ typedef struct {
 	SaAmfProtectionGroupTrackCallbackT
 		saAmfProtectionGroupTrackCallback;
 	SaAmfExternalComponentInstantiateCallbackT
-		saAmfProxiedComponentInstantiateCallback;
+		saAmfExternalComponentInstantiateCallback;
 	SaAmfExternalComponentCleanupCallbackT
-		saAmfProxiedComponentCleanupCallback;
+		saAmfExternalComponentCleanupCallback;
 } SaAmfCallbacksT;
 
 /*
@@ -383,7 +384,7 @@ saAmfProtectionGroupTrack (
 	SaAmfHandleT amfHandle,
 	const SaNameT *csiName,
 	SaUint8T trackFlags,
-	const SaAmfProtectionGroupNotificationT *notificationBuffer);
+	SaAmfProtectionGroupNotificationBufferT *notificationBuffer);
 
 SaAisErrorT
 saAmfProtectionGroupTrackStop (
