@@ -1,10 +1,10 @@
-
 /*
  * Copyright (c) 2002-2005 MontaVista Software, Inc.
+ * Copyright (c) 2006-2007 Red Hat, Inc.
  *
  * All rights reserved.
  *
- * Author: Steven Dake (sdake@mvista.com)
+ * Author: Steven Dake (sdake@redhat.com)
  *
  * This software licensed under BSD license, the text of which follows:
  * 
@@ -872,7 +872,7 @@ saAmfProtectionGroupTrack (
 	SaAmfHandleT amfHandle,
 	const SaNameT *csiName,
 	SaUint8T trackFlags,
-	const SaAmfProtectionGroupNotificationT *notificationBuffer)
+	SaAmfProtectionGroupNotificationBufferT *notificationBuffer)
 {
 	struct amfInstance *amfInstance;
 	struct req_lib_amf_protectiongrouptrack req_lib_amf_protectiongrouptrack;
@@ -884,7 +884,7 @@ saAmfProtectionGroupTrack (
 	memcpy (&req_lib_amf_protectiongrouptrack.csiName, csiName,
 		sizeof (SaNameT));
 	req_lib_amf_protectiongrouptrack.trackFlags = trackFlags;
-	req_lib_amf_protectiongrouptrack.notificationBufferAddress = (SaAmfProtectionGroupNotificationT *)notificationBuffer;
+	req_lib_amf_protectiongrouptrack.notificationBufferAddress = (SaAmfProtectionGroupNotificationBufferT *)notificationBuffer;
 
 	error = saHandleInstanceGet (&amfHandleDatabase, amfHandle,
 		(void *)&amfInstance);
